@@ -231,7 +231,7 @@ class Microservices(BaseClass, ABC):
         """
         return base64.b64encode(str.encode(json.dumps(json_in)))
 
-    def without_response(self, topic, data={}, id_transaction=None):
+    def without_response(self, topic, data={}, id_transaction=None, action=None):
         """
             Metodo para el envio de una peticion a un topico, sin esperar
             una respuesta del mismo.
@@ -261,13 +261,15 @@ class Microservices(BaseClass, ABC):
                     "bifurcacion": False,
                     "time": "",
                     "from": socket.gethostname(),
-                    "method": "GET",
+                    "method": "GET" if action is None else action,
                     "deviceType": "",
                     "span": None,
                     "filters": None,
                 },
                 "data": data,
-                "headers": {}
+                "headers": {
+                    "Asynchronous": False
+                }
             }, id_trans)
 
     def _message(self, msg):
